@@ -469,7 +469,10 @@ def calcEdefCorrectionVASP():
             print("  WARNING:: charge_state in input is not equal to charge in defect cell")
             foutlog.write("  WARNING:: charge_state in input is not equal to charge in defect cell\n")
     foutlog.write("  charge_state (adopted) = "+str(charge_state)+"\n")
-
+    if np.fabs(charge_state)<1e-10:
+        print("  ERROR:: Electrostatic energy cannot be calculated because charge_state is zero!")
+        foutlog.write("  ERROR:: Electrostatic energy cannot be calculated because charge_state is zero!\n")
+        sys.exit()
     # making elemslist
     elemslist_bulk=[]
     for i1,n1 in enumerate(natoms_bulk):
@@ -510,7 +513,7 @@ def calcEdefCorrectionVASP():
         args_rdiff=np.argsort(rdiff_list)
         if min(rdiff_list)>rtol_vac:
             def0_posi.append(copy.copy(p1))
-            def0_elems.append("Vac")
+            def0_elems.append("Vac_"+elemslist_bulk[ip1])
             continue
         e1=elemslist_bulk[ip1]
         pot1=pot_bulk[ip1]
@@ -540,45 +543,47 @@ def calcEdefCorrectionVASP():
         print("  Error:: no defect is detedted.")
         print("    Please try to adjust rtol_vac-parameter in the input file")
         foutlog.write("  Error:: no defect is detected\n")
-        foutlog.write("    Please try to adjust rtol_vac-parameter in the input file")
+        foutlog.write("    Try to adjust rtol_vac-parameter in the input file\n")
         sys.exit()
     if len(def0_elems)>1:
         print("  Warning:: complex defects are detected.")
-        foutlog.write("  Warning:: complex defects are detected.")
-    else:
-        foutlog.write("    The number of defects = "+str(len(def0_elems))+"\n")
-        foutlog.write("    Position_direct("+def0_elems[0]+") = "+str(def0_posi[0][0])+" "+str(def0_posi[0][1])+" "+str(def0_posi[0][2])+"\n")
-        averaged_posi=[0.0,0.0,0.0] 
-        p1=def0_posi[0]
-        for id2 in range(1,len(def0_elems)):
-            p2=def0_posi[id2]
-            foutlog.write("    Position_direct("+def0_elems[id2]+") = "+str(p2[0])+" "+str(p2[1])+" "+str(p2[2])+"\n")
-            pdiff1=[p2[0]-p1[0],p2[1]-p1[1],p2[2]-p1[2]]
-            rdiff2min=1e10
-            for s0 in [-1,0,1]:
-                for s1 in [-1,0,1]:
-                    for s2 in [-1,0,1]:
-                        pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
-                        pdiff2=[0.0,0.0,0.0]
-                        for i1 in range(3):
-                            for i2 in range(3):
-                                pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
-                        rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
-                        if rdiff2<rdiff2min:
-                            rdiff2min=rdiff2
-                            pdiff3min=copy.copy(pdiff3)
-            for i1 in range(3):
-                averaged_posi[i1]+=pdiff3min[i1]
+        foutlog.write("    Warning:: complex defects are detected.\n")
+        foutlog.write("      When this is unexpected, ...\n")
+        foutlog.write("      (1) check the structure for confirming your expection.\n")
+        foutlog.write("      (2) try to adjust rtol_vac-parameter in the input file.\n")
+    foutlog.write("    The number of defects = "+str(len(def0_elems))+"\n")
+    foutlog.write("    Defect_position_direct("+def0_elems[0]+") = "+str(def0_posi[0][0])+" "+str(def0_posi[0][1])+" "+str(def0_posi[0][2])+"\n")
+    averaged_posi=[0.0,0.0,0.0] 
+    p1=def0_posi[0]
+    for id2 in range(1,len(def0_elems)):
+        p2=def0_posi[id2]
+        foutlog.write("    Defect_position_direct("+def0_elems[id2]+") = "+str(p2[0])+" "+str(p2[1])+" "+str(p2[2])+"\n")
+        pdiff1=[p2[0]-p1[0],p2[1]-p1[1],p2[2]-p1[2]]
+        rdiff2min=1e10
+        for s0 in [-1,0,1]:
+            for s1 in [-1,0,1]:
+                for s2 in [-1,0,1]:
+                    pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                    pdiff2=[0.0,0.0,0.0]
+                    for i1 in range(3):
+                        for i2 in range(3):
+                            pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                    rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                    if rdiff2<rdiff2min:
+                        rdiff2min=rdiff2
+                        pdiff3min=copy.copy(pdiff3)
         for i1 in range(3):
-            averaged_posi[i1]=p1[i1]+averaged_posi[i1]/len(def0_elems)
-        if len(def0_elems)>1:
-            foutlog.write("    Position_direct(ave.) = "+str(averaged_posi[0])+" "+str(averaged_posi[1])+" "+str(averaged_posi[2])+"\n")
+            averaged_posi[i1]+=pdiff3min[i1]
+    for i1 in range(3):
+        averaged_posi[i1]=p1[i1]+averaged_posi[i1]/len(def0_elems)
+    if len(def0_elems)>1:
+        foutlog.write("    Defect_position_direct(ave.) = "+str(averaged_posi[0])+" "+str(averaged_posi[1])+" "+str(averaged_posi[2])+"\n")
     posi_def0=averaged_posi
     if "defect_position_direct" in input_parameters:
         print("  WARNING::  defect position is overwritten by defect_position_direct param.")
         foutlog.write("  WARNING:: defect position is overwritten by defect_position_direct param.\n")
         posi_def0=input_parameters["defect_position_direct"]
-    foutlog.write("    Position_direct(adopted) = "+str(posi_def0[0])+" "+str(posi_def0[1])+" "+str(posi_def0[2])+"\n")
+    foutlog.write("  Defect_position_direct(adopted) = "+str(posi_def0[0])+" "+str(posi_def0[1])+" "+str(posi_def0[2])+"\n")
     foutlog.flush()
     ##### rdist from defect
     rdist=[]
@@ -651,6 +656,30 @@ def calcEdefCorrectionVASP():
     pot_Model=[]
     pot_residual=[]
     for ip1,p1 in enumerate(posi_def):
+        flag_defsite=False
+        for ip0,p0 in enumerate(def0_posi):
+            pdiff1=np.array([p1[0]-p0[0],p1[1]-p0[1],p1[2]-p0[2]])
+            rdiff2min=1e10
+            for s0 in [-1,0,1]:
+                for s1 in [-1,0,1]:
+                    for s2 in [-1,0,1]:
+                        pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                        pdiff2=[0.0,0.0,0.0]
+                        for i1 in range(3):
+                            for i2 in range(3):
+                                pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                        rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                        if rdiff2<rdiff2min:
+                            rdiff2min=rdiff2
+                            pdiff3min=copy.copy(pdiff3)
+            relvect=np.dot(latt_def,pdiff3min)
+            r_relvect=np.linalg.norm(relvect)
+            if r_relvect<1e-10:
+                flag_defsite=True
+        if flag_defsite:
+            pot_Model.append(None)
+            pot_residual.append(None)
+            continue
         pdiff1=np.array([p1[0]-posi_def0[0],p1[1]-posi_def0[1],p1[2]-posi_def0[2]])
         rdiff2min=1e10
         for s0 in [-1,0,1]:
@@ -667,10 +696,6 @@ def calcEdefCorrectionVASP():
                         pdiff3min=copy.copy(pdiff3)
         relvect=np.dot(latt_def,pdiff3min)
         r_relvect=np.linalg.norm(relvect)
-        if r_relvect<1e-10:
-            pot_Model.append(None)
-            pot_residual.append(None)
-            continue
         pot_real=epot_real.calcpot_atom(relvect)
         pot_recip=epot_recip.calcpot_atom(relvect)
         pottot=coeff1*(pot_real+pot_recip+Ebg/coeff2)
