@@ -78,6 +78,9 @@ def pydecs_main():
         os.makedirs(dirname,exist_ok=True)
         os.chdir(dirname)
         defect_densities=solver1.opt_coordinator(eqc1,inparams["solver"],root_outfiles,inparams["plot"])
+        if defect_densities is None:
+            os.chdir("../")
+            return None
         if not inparams["solver"]["just_plot_Edef"]:
             defect_densities[0][-1]=ieq1+1
             output_density_with_eqcond(defect_densities,eqc1,fnout_dens_csv)
@@ -87,20 +90,24 @@ def pydecs_main():
         pool1.map(calc_defect_densities,range(len(eqcond1list)))
     if not inparams["solver"]["just_plot_Edef"]:
         fout1=open(fnout_dens_csv,"w")
+        icnt1=0
         for ieq1 in range(len(eqcond1list)):
             ieq1str=f"{ieq1+1:0>4}"
             dirname1=f"cond{ieq1str}"
             fnin1=dirname1+"/"+fnout_dens_csv
-            fin1=open(fnin1).readlines()
-            if ieq1==0:
-                for l1 in fin1:
-                    fout1.write(l1)
-            else:
-                fout1.write(fin1[-1])
+            if os.path.exists(fnin1):
+                fin1=open(fnin1).readlines()
+                if icnt1==0:
+                    for l1 in fin1:
+                        fout1.write(l1)
+                else:
+                    fout1.write(fin1[-1])
+                icnt1+=1
         fout1.close()
         inparams["plot"]["outfiles_header"]=root_outfiles
         inparams["plot"]["input_filename"]=fnout_dens_csv
-        plot_defect_densities(inparams["plot"])
+        if icnt1>1:
+            plot_defect_densities(inparams["plot"])
     print("*"*100)
     print(f" Finished!")
     print("*"*100)
