@@ -363,7 +363,6 @@ class DefectEqSolver:
         fout.write(f" ------ Starting step-wize minimization with step size of {step_size} -----\n")
         residArray0=func_resid(cp0)
         if residArray0 is None:
-            print("test-D00")
             return (None,None)
         resid0=np.sqrt(np.square(residArray0).mean(axis=0))
         vect_ms=0.0
@@ -380,7 +379,6 @@ class DefectEqSolver:
         while i_loop<maxiter:
             residArray1=func_resid(cp1)
             if residArray1 is None:
-                print("test-D01")
                 return (None,None)
             resid1=np.sqrt(np.square(residArray1).mean(axis=0))
             if resid1>resid0:
@@ -403,7 +401,6 @@ class DefectEqSolver:
                 cp2.append(x_in*cp0[i1]+(1.0-x_in)*cp1[i1])
             residArray2=func_resid(cp2)
             if residArray2 is None:
-                print("test-CHK00")
                 raise LineOptError("Minimization error!")
                 # return 0.0
             resid2=np.sqrt(np.square(residArray2).mean(axis=0))
@@ -417,7 +414,6 @@ class DefectEqSolver:
             cp3.append(res3.x*cp0[i1]+(1.0-res3.x)*cp1[i1])
         residArray3=func_resid(cp3)
         if residArray3 is None:
-            print("test-Z00")
             return (None,None)
         resid3=np.sqrt(np.square(residArray3).mean(axis=0))
         print("finished: opt_steady_line_minimization")
@@ -428,7 +424,6 @@ class DefectEqSolver:
         delta_cp2=delta_cp
         residArray2=func_resid(cp2)
         if residArray2 is None:
-            print("test-B02")
             return (None,None)
         vgrad2=func_grad(residArray2)
         resid2=np.sqrt(np.square(residArray2).mean(axis=0))
@@ -473,7 +468,6 @@ class DefectEqSolver:
             fout.write(f" ----- Gradient for the line search = {cgvect2} -----\n")
             (cp3,residArray2)=self.opt_steady_line_minimization(func_resid,cgvect2,cp2,delta_cp2,fout,tol,maxiter)
             if residArray2 is None:
-                print("test-B01")
                 return (None,None)
             if damping_rate=="DividedByNsteps":
                 delta_cp2=delta_cp/(iloop1+2.0)
@@ -568,7 +562,6 @@ class DefectEqSolver:
                 cp1[Natoms_elem_list[icp1]]=cp_in1
             out_defect_densities=self.opt_Nsites_for_chempots(temperature_in,cp1,opt_params_in,root_outfiles)
             if out_defect_densities is None:
-                print("test-A01")
                 return None
             del_nat_array=[]
             nat_array=[]
@@ -594,7 +587,6 @@ class DefectEqSolver:
                 fout1,opt_params_in["opt_Natoms_tol"],
                 opt_params_in["opt_Natoms_maxloop"])
         if Natoms_chempot_results_list is None:
-            print("test-F01")
             return None
         print(" [opt_Natoms] Finished")
         cp_list=copy.deepcopy(chempots_in)
@@ -655,7 +647,6 @@ class DefectEqSolver:
                     eq1["chempot_init"]=self.chempots_fixNatoms[e1]
             defect_densities=self.opt_Natoms(temp,chempots,eq_cond_in[self.eqlabel_fixNatoms],solver_params_in,root_outfiles,plot_params_in)
             if defect_densities is None:
-                print("test-E00")
                 return None
             if solver_params_in["opt_Natoms_chempot_init"]=="update":
                 self.chempots_fixNatoms={}
